@@ -138,11 +138,15 @@ class tables(str, Enum):
 
 async def aiter(list: List):
     for i in list:
-        yield orjson.dumps(i, option=orjson.OPT_APPEND_NEWLINE)
+        if isinstance(i, str):
+            yield i.replace("\\n", "\\\\n").replace("\\t", "\\\\t")
+        else:
+            yield orjson.dumps(i, option=orjson.OPT_APPEND_NEWLINE).decode(
+                "utf-8"
+            ).replace("\\n", "\\\\n").replace("\\t", "\\\\t")
 
 
 async def copy(iter, table: tables, conn: asyncpg.Connection):
-    print(list(table))
     logger.debug(f"copying to {table} directly")
     if isinstance(iter, List):
         logger.debug("Converting List into Async Iterator")
